Generic function computing the Akaike Information Criterion of
the model x, with the list of sequences sequences.
aic(x, sequences = NULL)An object for which there exists a loglik attribute if
sequences = NULL or a loglik method otherwise.
Optional. A list of vectors representing the sequences for
which the AIC will be computed based on x using the method loglik.
Value of the AIC.